<?php
/*
// $Id: coursepicker_handler.inc.php 770 2009-05-22 17:37:21Z anwosu $
// $Rev: 770 $
// $Date: 2009-05-22 13:37:21 -0400 (Fri, 22 May 2009) $
// $Author: anwosu $
// $URL: https://svn.brown.edu/svn/sys-srv/gateway/trunk/coursepicker_handler.inc.php $
*/

// course picker form processing code
// must go at the top of the page to issue a redirect
// set $coursepicker_destination to URL for successful submission

$picker_errors = array();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
	$picker_request = $_POST;
}
else {
	$picker_request = $_GET;
}

// set default values then update from request
$req_term = ""; $err_term = false;
$req_code = ""; $err_code = false;
$req_crn = ""; $err_crn = false;
$req_frombanner = true;
$d_req_course = $req_course = ""; $err_course = false;
$d_req_section = $req_section = ""; $err_section = false;
$req_submit = false;

if (array_key_exists('term', $picker_request)) {
  $req_term = $picker_request['term'];
}
if (array_key_exists('code', $picker_request)) {
  $req_code = $picker_request['code'];
}
if (array_key_exists('course', $picker_request)) {
  $req_crn = $picker_request['course'];
}
if (array_key_exists('select_opt', $picker_request)) {
  $req_frombanner = $picker_request['select_opt'] === "listed";
}
if (array_key_exists('course_number', $picker_request)) {
  $req_course = trim($picker_request['course_number']);
  $d_req_course = htmlentities($req_course);
}
if (array_key_exists('section_number', $picker_request)) {
  $req_section = trim($picker_request['section_number']);
  $d_req_section = htmlentities($req_section);
}
if (array_key_exists('submit', $picker_request)) {
  $req_submit = true;
}

// handle submit 
if ($req_submit) {
	// handle Banner course
	if ($req_frombanner) {
		if ($req_crn === "") {
			$picker_errors[] = "No course was selected";
			$err_crn = true;
		}
		else {
			$result_crn = valid_crn($req_crn);
			if ($result_crn !== "") {
				header(sprintf("Location: %s?crs=%s",
							   $coursepicker_destination, $result_crn));
				exit();
			}
			else {
				$picker_errors[] = "Course \"$req_crn\" is not valid";
				$err_crn = true;
			}
		}
	}

	// handle non-Banner Course
	else {
		if ($req_term === "") {
			$picker_errors[] = "No term was selected";
			$err_term = true;
		}
		else {
			$result_term = valid_term($req_term);
			if ($result_term === "") {
				$picker_errors[] = "Term \"$req_term\" is not valid";
				$err_term = true;
			}
		}		

		if ($req_code === "") {
			$picker_errors[] = "No department was selected";
			$err_code = true;
		}
		else {
			$result_code = valid_code($req_code);
			if ($result_code === "") {
				$picker_errors[] = "Department code \"$req_code\" is not valid";
				$err_code = true;
			}
		}		

		if ($req_course === "") {
			$picker_errors[] = "No course number was entered";
			$err_course = true;
		}
		else {
			$result_course = valid_course($req_course);
			if ($result_course === "") {
				$picker_errors[] = "Course number \"$req_course\" is not valid";
				$err_course = true;
			}
		}		

		if ($req_section === "") {
			$picker_errors[] = "No section number was entered";
			$err_section = true;
		}
		else {
			$result_section = valid_section($req_section);
			if ($result_section === "") {
				$picker_errors[] = "Section number \"$req_section\" is not valid";
				$err_section = true;
			}
		}		

		if (sizeof($picker_errors) == 0) {
			$result_crn = sprintf("%s:%s:%s:%s",
				$result_code, $result_course, $result_term, $result_section);
			header(sprintf("Location: %s?crs=%s",
						   $coursepicker_destination, $result_crn));
			exit();
		}
	}
}

function valid_term($term) {
	$fields = explode('-', $term);
	if (sizeof($fields) != 2) return "";
	$year = (int)$fields[0];
	if (($year < 2000) || ($year > 2100)) return "";
	switch (strtolower($fields[1])) {
		case 'spring':
			return "$year-Spring";
		case 'summer':
			return "$year-Summer";
		case 'fall':
			return "$year-Fall";
		default:
			return "";
	}
	return "";
}

function valid_code($code) {
	$code = strtoupper($code);
	if (preg_match('/^[A-Z]{3,4}$/', $code)) {
		return $code;
	}
	return "";
}

function valid_crn($crn) {
	$fields = explode(':', $crn);
	if (sizeof($fields) != 4) return "";
	$code = valid_code($fields[0]);
	if ($code === "") return "";
	$course = valid_course($fields[1]);
	if ($course === "") return "";
	$term = valid_term($fields[2]);
	if ($term === "") return "";
	$section = valid_section($fields[3]);
	if ($section === "") return "";
	return sprintf("%s:%s:%s:%s",
		$code, $course, $term, $section);
}

function valid_course($course) {
	$course = strtoupper($course);
	if (preg_match('/^[0-9]{4,4}[A-Z0-9]{0,2}$/', $course)) {
		return $course;
	}
	return "";
}

function valid_section($section) {
	$section = strtoupper($section);
	if (preg_match('/^[A-Z0-9]{3,3}$/', $section)) {
		return $section;
	}
	return "";
}

?>
