<?php
# brown_breadcrumbs.class.php
# Brown University
#
# Automatically create a breadcrumb trail based on the URL of a web page.
#
# Last Edit:
# John Pennypacker - John_Pennypacker@brown.edu
# 2008-06-20

class Brown_Breadcrumbs {
								

	public $page_title;
	public $path;
	public $server;
	public $show_server = TRUE;
	public $separator;
	public $crumbs = array();
	public $exceptions = array();
		
/**
 * Class Constructor
 * Instatiate a new breadcrumb object
 * 
 * @param	$page_title		The title of the page we're viewing. 
 * @param	$path			The URI of the file.  uses $_SERVER['REQUEST_URI'] by default
 * @param	$servername		The server name.
 * @return	boolean			True if connection succeed, false otherwise.
 */
	public function __construct($page_title='', $path='', $servername='') {
	
			if(!empty($servername)) {
				// return nothing if the web site isn't Brown
				// this is so I can develop on my local machine, there's probably a better fix.
				if(stripos($_SERVER['SERVER_NAME'], "brown.edu" === FALSE)) {
					return FALSE;
				}
				$this->server = $servername;
			} else {
				$this->server = $_SERVER['SERVER_NAME'];
			}

			if(!empty($path)) {
				$this->path = $path;
			} else {
				// if we don't have a path to work with, this isn't going to work.
				$this->path = $_SERVER['REQUEST_URI'];
			}

			if(!empty($page_title)) {
				$this->setPageTitle($page_title);
			}

			$this->addReplacement("brown.edu", "Brown");
			$this->addReplacement("www.brown.edu", "Brown");
			
	}



/**
 * This does the work.  It converts the path to an array of name and href values.
 * 
 * @return	boolean
 */
	public function getBreadcrumb() {
	

			// re-initialize the crumbs just in case something got in there
			$this->crumbs = array();
								
			// break up the path into bits by slashes
			$bits = explode("/", $this->path);
			
			$tier="//" . $this->server;
			
			if($this->show_server == TRUE) { // Set the first element to be the server

				$this->crumbs[] = array	(
										 "name" => $this->formatBreadcrumb($this->server)
										,"href" => $tier
									);
			}
			
			// now loop through the bits to build a final output array that's easy to use.
			for($i=0; $i<count($bits); $i++) {
			
					
				if(!empty($bits[$i])) {
					$tier .= "/" . $bits[$i];
					if($bits[$i] != 'Student_Services') {
				
						$this->crumbs[] = array	(
											 "name" => $this->formatBreadcrumb($bits[$i])
											,"href" => $tier
										);
				
					}
				}
			}

			// now let's tack on the page title.
			if(!empty($this->page_title)) {
				if($this->show_server == TRUE && count($this->crumbs) == 1) {
					// if we're showing the server and it's the only item in the breadcrumb,
					// append an element for the page title
					$this->crumbs[]['name'] = $this->page_title;
				} else {
					// otherwise replace the last element with the page title
					$this->crumbs[count($this->crumbs)-1]['name'] = $this->page_title;
				}
			}
			

	
		return TRUE;
	} //end getBreadcrumb




/**
 * Sets the title of the page
 * 
 * @param	$s			The title of the document
 * @return	boolean
 */

	public function setPageTitle($s) {
		if(isset($this->exceptions[$s])) {
			$this->page_title = $this->exceptions[$s];
		} else {
			$this->page_title = $s;
		}
	} // end setPageTitle()


/**
 * Reformats each element of the breadcrumb
 * 
 * @param	$s			A piece of URL
 * @return	string		A refromatted text for the breadcrumb link
 */

	public function formatBreadcrumb($s) {
		if(isset($this->exceptions[$s])) {
			return $this->exceptions[$s];
		} else {
			return ucwords(str_replace(array("-","_"), " ", $s));
		}
	} // end formatBreadcrumb()



/**
 * replace the exceptions array with a new array of name=>replacment pairs.
 *
 * @param	$a			an array or replacments
 *
 * @return	boolean
 */

	public function loadReplacements($a) {
		if(!empty($a) && is_array($a)) {
			$this->exceptions = $a;
		} else {
			return FALSE;
		}
	} // end loadReplacements()


/**
 * Add additional exceptions to replace in the breadcrumbs
 * if the replacment is already defined, it will be overwritten with the new value
 *
 * @param	$key		the name to find
 * @param	$val		the word to replace the name with
 *
 * @return	boolean
 */

	public function addReplacement($key, $val) {
		if(!empty($key) && !empty($val)) {
			$this->exceptions[$key] = $val;
		} else {
			return FALSE;
		}
	} // end addReplacement()



/**
 * Accessor method to get at the crumbs
 *
 * @return	array		the breadcrumbs array
 *						false if there are none.
 */

	public function getCrumbs() {

		$this->getBreadcrumb();
	
		if(!empty($this->crumbs)) {
			return $this->crumbs;
		} else {
			return FALSE;
		}

	} // end getCrumbs()


/**
 * Setter method to specify html crumb separators
 *
 * @return	boolean
 */

	public function setSeparator($s) {
	
		if(!empty($s)) {
			$this->separator = $s;
			return TRUE;
		} else {
			return FALSE;
		}

	} // end setSeparator()




/**
 * Generates the HTML list of a breadcrumb.
 * 
 * @param	$list		"ol" is default.  Anything else makes it a ul
 * @return	string		A formatted HTML list of breadcrumbs.
 */
	public function outputHTML($list="ol") {
	
		if($crumbs = $this->getCrumbs()) {
			$list = ($list == "ol") ? $list : "ul";
		
			$html = '<'. $list .' id="breadcrumb">';
			$count=0;
			
			
			foreach($crumbs as $c) {
				$html .= '<li';
				if($count == 0) { 
					$html .= ' class="first"'; 
				} elseif($count == count($crumbs)-1) { 
					$html .= ' class="last"'; 
				}
				$html .= '>';
				
				if($count != 0 && !empty($this->separator)) { 
					$html .= $this->separator; 
				}

				if($count == count($crumbs)-1) { 
					$html .= $c['name'] .'</li>';
				} else {
					$html .= '<a href="'. $c['href'] .'">'. $c['name'] .'</a></li>';
				}
				
				$count++;
			}
	
			$html .= '</'. $list .'>';
			
			return $html;
			
		} else {
		
			return FALSE;
			
		}
		
	
	}


}


?>