<?php
# functions.php
# Brown University
# John Pennypacker
# John_Pennypacker@brown.edu
# 2008-04-20


/**
 * What's up with the class?
 * 
 * I wanted to make sure that all the functions herein exist in their own namespace.
 * some have pretty generic names, and I don't want that they conflict with custom 
 * scripts that folks add later.
 *
 * Wanna use one of these in your script but don't know how?  Here's the syntax:
 * CISFunctions::function_name();
 * and an example:
 * CISFunctions::format_phone('4015551212');
 */

Class CISFunctions {

	/**
	 * This is basically the same as var_dump, but a little customized.
	 * 
	 * @param	$e			Any variable
	 * @return	string		returns a string of HTML
	 */
	function report($e) {
		echo "<pre>\n";
	
		if ($e === TRUE) {
			echo "Boolean TRUE";
		} elseif ($e === FALSE) {
			echo "Boolean FALSE";
		} elseif ($e === NULL) {
			echo "Nullsies";
		} elseif (is_object($e)) {
			echo $e;
		} else {
			print_r($e);
		}
	
		echo "</pre><br />\n";
	} // end report()
	
	
	/**
	 * formats a phone number in (ddd) ddd-dddd format.
	 * 
	 * @param	$phone		A phone number.  Formatting doesn't matter as long as it has 10 digits
	 *						or 11 digits if it begins with a 1.
	 * @return	string		returns a formatted phone number as a string.
	 */
	function format_phone($phone='') {
		$phone = preg_replace("/\D/", "", $phone);
	
		if(!empty($phone) && $phone{0} == 1) { //if the number starts with a 1, remove it
			$phone = substr($phone, 1);
		}
		
		if(strlen($phone) == 10) {
			$areacode = substr($phone,0,3);
			$exchange = substr($phone,3,3);
			$digits = substr($phone,6,4);
		}
		
		return "(" . $areacode . ") " . $exchange . "-" . $digits;
		
	} //end format_phone()
	
	
	/**
	 * Creates a breadcrumb for the current page.
	 * 
	 * @return	array		An array of elements that represents that path to the page from root.
	 */
	
	function get_breadcrumb() {
		global $page_title;
		
		//return nothing if the web site isn't Brown
		if(stripos($_SERVER['SERVER_NAME'], "brown.edu" === FALSE)) return FALSE;
	
		//break up the URI into bits by slashes
		$bits = explode("/", $_SERVER['REQUEST_URI']);
		
		$output = array(
					array	(
						 "name" => "Brown University"
						,"href" => "https://www.brown.edu"
					)
				);
		$tier="//" . $_SERVER['SERVER_NAME'];
		//now loop through the bits to build a final output array that's easy to use.
		for($i=0; $i<count($bits); $i++) {
		
			if((!empty($bits[$i])) || ($bits[$i] != 'Departments')) {
				$tier .= "/" . $bits[$i];
				if($i<count($bits)-1 && !empty($page_title)) {
					$output[] = array	(
											 "name" => CISFunctions::format_breadcrumb($bits[$i])
											,"href" => $tier
										);
				} else {
					$output[] = array	(
											 "name" => $page_title
											,"href" => $tier
										);
				}
			}
			
		}
		
		return $output;
	} //end get_breadcrumb
	
	
	
	
	/**
	 * Reformats each element of the breadcrumb
	 * 
	 * @param	$s			A piece of URL
	 * @return	string		A refromatted text for the breadcrumb link
	 */
	
	function format_breadcrumb($s) {
		// load up the exceptions
		$path = "breadcrumb-exceptions.php";
		$op = "./". OVERRIDE_DIRECTORY ."/". $path;
		if(file_exists($op)) {
			include($op);
		} else {
			include($path);
		}
		
		if(isset($exceptions[$s])) {
			return $exceptions[$s];
		} else {
	
			$words = explode(" ", ucwords(str_replace(array("-","_"), " ", $s)));
			$str = '';
			for($i=0; $i<count($words); $i++) {
				if($i != 0) {
					$words[$i] = (array_key_exists($words[$i], $lower_caps)) ? $lower_caps[$words[$i]]: $words[$i];
				}
				if($i >= 0) {
					$words[$i] = (array_key_exists($words[$i], $strange_caps)) ? $strange_caps[$words[$i]]: $words[$i];
				}
			}
			$str = implode(" ", $words);
			return $str;
		}
		
	} // end format_breadcrumb()
	
	
	
	
	
	function analyze_uri() {
		if(!empty($_SERVER['REQUEST_URI'])) {
			// validate to ensure there are no leading period
			// which could be a sly way to switch directories.
			$uri = explode("/", $_SERVER['REQUEST_URI']);
			foreach($uri as $k=>$v) {
				if(substr($v, 0, 1) == '.') {
					unset($uri[$k]);
				}
			}
			$action = array_slice($uri, 1);
			while(empty($action[count($action)-1])) { //pop empty url bits off the end of the array
				unset($action[count($action)-1]);
			}
			return $action;
		} else {
			return false;
		}
	} //end analyze_uri
	

}

	function set_visibility($menu_uri) {

		//default is to hide submenus
		$css_class = '';
		
		// pull out parent dir from the menu uri
		$menu_dir = substr($menu_uri, strlen(BASEHREF));
		
		// find out where the user is in the site and pull out parent dir 
		$current_filepath = substr($_SERVER['SCRIPT_URI'], strlen(BASEHREF));
		$current_file = strrchr($_SERVER['SCRIPT_URI'], '/');
		$length = strlen($current_filepath) - strlen($current_file) +1;
		$current_dir = substr($current_filepath, 0, $length);
		
		//compare menu directory to user's location dir
		if ($menu_dir == $current_dir) {
			$css_class = ' class="current"';
		}
		return $css_class;
	}

?>
