<?php
# mysql.class.php
# Brown University
# John Pennypacker
# John_Pennypacker@brown.edu
# 2008-07-08

class MySQL {
	public $persistent = NULL;
	public $conn = NULL;
	public $result = false;

	public $message = array();
	public $err = array();

	private $host;
	private $user;
	private $pass;
	private $database;



/**
 * Class Constructor
 * 
 * Grabs the database credentials from the $GLOBALS data set in the config file.
 * 
 * @param	$db			The name of the database to use
 * @return	boolean		TRUE if a db connection is established, false on error
 */
	public function __construct($db='') {
	
		if(!isset($GLOBALS['db_credentials'])) {
			$this->AddError("Make sure that you've set the proper database credentials in config.php!");
			return FALSE;
		}
		
		$this->host = $GLOBALS['db_credentials']['hostname'];
		$this->user = $GLOBALS['db_credentials']['username'];
		$this->pass = $GLOBALS['db_credentials']['password'];
		
		if($db == '') {
			$this->database = $GLOBALS['db_credentials']['database'];
		} else {
			$this->database = $db;
		}
		
		//might as well unset the credentials at this point
		unset($GLOBALS['db_credentials']);
		
		if ($this->persistent) {
			$func = 'mysql_pconnect';
		} else {
			$func = 'mysql_connect';
		}
		
		$this->conn = $func($this->host, $this->user, $this->pass);

		if (!$this->conn) {
			return false;
		}
			
		if (@!mysql_select_db($this->database, $this->conn)) {
			return false;
		}
		return true;
	}

/**
 * Returns a simple string when this object is queried
 *
 * @return	string	
 */
	public function __toString() {
		return "MySQL Object";
	}


/**
 * Closes the mysql connection to the database
 *
 * @return	boolean
 */
	public function Close() {
		return(@mysql_close($this->conn));
	}

/**
 * Selects a new database
 *
 * @return	boolean
 */
	public function SelectDb($name) {
		$this->database = $name;
		if (@!mysql_select_db($this->database, $this->conn)) {
			return false;
		} else {
			return true;
		}
	}
	
/**
 * Reports an error from MySQL
 *
 * @return	string
 */
	public function Error() {
		return (mysql_error());
	}


/**
 * Queries the database, and reports errors on failure
 *
 * @param	$sql		An SQL statement.
 * @return	resource	Returns a database resource or false if there was a problem
 */
	public function Query($sql) {
		$this->result = @mysql_query($sql, $this->conn);
		if($e = $this->Error()) {
			$this->AddError("MySQL Error: " . $this->Error());
		}
		return($this->result != false);
	}

	
/**
 * Pass-through for php's mysql_affected_rows()
 */
	public function AffectedRows() {
		return(@mysql_affected_rows($this->conn));
	}
/**
 * Pass-through for php's mysql_num_rows()
 */
	public function NumRows() {
		return(@mysql_num_rows($this->result));
	}
/**
 * Pass-through for php's mysql_fetch_object()
 */
	public function FetchObject() {
		return(@mysql_fetch_object($this->result, MYSQL_ASSOC));
	}
/**
 * Pass-through for php's mysql_fetch_array(); stripslashes() is run on all results.
 */
	public function FetchArray() {
		return (@mysql_fetch_array($this->result, MYSQL_NUM));
	}
/**
 * Pass-through for php's mysql_fetch_assoc(); stripslashes() is run on all results.
 */
	public function FetchAssoc() {
		return (@mysql_fetch_assoc($this->result));
	}
/**
 * Pass-through for php's mysql_real_escape_string()
 */
	public function Escape($var) {
		return(@mysql_real_escape_string($var,$this->conn));
	}
/**
 * Pass-through for php's mysql_insert_id()
 */
	public function GetInsertId() {
		return(@mysql_insert_id());
	}
	
/**
 * Gets the column names for a table
 * 
 * @param	$table_name		Takes the name of a database table
 * @return	array			Returns an array of column names; FALSE on error
 */
	public function GetColumns($table_name) {
		$sql = "SHOW COLUMNS FROM $table_name";
		return $this->Get($sql);
	} //end GetColumns

/**
 * Records an error
 * 
 * @param	$m			the error message
 */
	public function AddError($m) {
		$this->err[] = $m;
	} //end AddError

/**
 * Records a message
 * 
 * @param	$m			the message
 */
	public function AddMessage($m) {
		$this->message[] = $m;
	} //end AddMessage



/**
 * Executes a database query and returns the result set.  All values are stripslashed.
 * 
 * @param	$sql		SQL statement
 * @return	array		returns a hash of all rows matched, or just the row if only one row matches
 */
	public function Get($sql) {
		$a = array();
		if($this->Query($sql)) {
			while($row = $this->FetchAssoc()) {
				$a[] = $row;
			}
			
			if(count($a) == 1) {
				return $a[0];
			} else {
				return $a;
			}
		} else {
			$this->AddError($this->Error());
			return false;
		}
	} //end Get

/**
 * Executes a database query and returns a single row.   All values are stripslashed.
 * 
 * @param	$sql		SQL statement
 * @return	array		returns one row as an array.
 */
	public function GetOne($sql) {
		if($this->Query($sql)) {
			return $this->FetchAssoc();
		} else {
			$this->AddError($this->Error());
			return false;
		}
	} //end Get

/**
 * Executes a database query and returns a hash even if just one row matches.   All values are stripslashed.
 * 
 * @param	$sql		SQL statement
 * @return	array		returns a hash of row(s) matched.
 */
	public function GetAll($sql) {
		$a = array();
		if($this->Query($sql)) {
			while($row = $this->FetchAssoc()) {
				$a[] = $row;
			}
			return $a;
		} else {
			$this->AddError($this->Error());
			return false;
		}
	} //end Get_all

}
?>